.. _fastq-utils:

fastq-utils - Fastq Utilities
=============================

Overview
--------

.. automodule:: mgkit.workflow.fastq_utils


Options
-------

.. click:: mgkit.workflow.fastq_utils:main
   :prog: fastq-utils
   :show-nested:
